3.0.0
-----

* BREAKING: Remove RPi.GPIO and bus autodetect
* BREAKING: Switch to smbus2

2.0.0
-----

* BREAKING: Port to class.
* Legacy support for module methods, auto-instantiates a class

1.2.7
-----

* Bugfix: Fix for Python 3.5

1.2.6
-----

* Initial commit to Raspbian apt repository

1.2.5
-----

* Initial commit to Raspbian apt repository

1.2.4
-----

* Added alternate warning/instructions for missing python3-smbus
* Code quality improvements

1.2.3
-----

* Print fix

1.2.2
-----

* Added i2c_bus_id detection for older Pi

1.2.1
-----

* Removed hard dependency upon SMbus, added message at runtime

1.0.0
-----

* Initial release

